# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.iot.devices.v1 import registry_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2
from yandex.cloud.iot.devices.v1 import registry_service_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class RegistryServiceStub(object):
    """A set of methods for managing registry.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/Get',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/GetByName',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetByNameRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/List',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/Create',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/Update',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/Delete',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListCertificates = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/ListCertificates',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesResponse.FromString,
                )
        self.AddCertificate = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/AddCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteCertificate = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/DeleteCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListPasswords = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/ListPasswords',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsResponse.FromString,
                )
        self.AddPassword = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/AddPassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeletePassword = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/DeletePassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryPasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListDeviceTopicAliases = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/ListDeviceTopicAliases',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesResponse.FromString,
                )
        self.ListDataStreamExports = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/ListDataStreamExports',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsResponse.FromString,
                )
        self.AddDataStreamExport = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/AddDataStreamExport',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddDataStreamExportRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteDataStreamExport = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/DeleteDataStreamExport',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteDataStreamExportRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.RegistryService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsResponse.FromString,
                )


class RegistryServiceServicer(object):
    """A set of methods for managing registry.
    """

    def Get(self, request, context):
        """Returns the specified registry.

        To get the list of available registries, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of registries in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a registry in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCertificates(self, request, context):
        """Retrieves the list of registry certificates for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCertificate(self, request, context):
        """Adds a certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCertificate(self, request, context):
        """Deletes the specified registry certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPasswords(self, request, context):
        """Retrieves the list of passwords for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPassword(self, request, context):
        """Adds password for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePassword(self, request, context):
        """Deletes the specified password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDeviceTopicAliases(self, request, context):
        """Retrieves the list of device topic aliases for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDataStreamExports(self, request, context):
        """Retrieves the list of YDS exports for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddDataStreamExport(self, request, context):
        """Adds YDS export for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteDataStreamExport(self, request, context):
        """Deletes the specified YDS export.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RegistryServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetByNameRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListCertificates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCertificates,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesResponse.SerializeToString,
            ),
            'AddCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.AddCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListPasswords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPasswords,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsResponse.SerializeToString,
            ),
            'AddPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeletePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryPasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListDeviceTopicAliases': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDeviceTopicAliases,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesResponse.SerializeToString,
            ),
            'ListDataStreamExports': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDataStreamExports,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsResponse.SerializeToString,
            ),
            'AddDataStreamExport': grpc.unary_unary_rpc_method_handler(
                    servicer.AddDataStreamExport,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddDataStreamExportRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteDataStreamExport': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteDataStreamExport,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteDataStreamExportRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.iot.devices.v1.RegistryService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class RegistryService(object):
    """A set of methods for managing registry.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/Get',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/GetByName',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.GetByNameRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__pb2.Registry.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/List',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistriesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/Create',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.CreateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/Update',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.UpdateRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/Delete',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCertificates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/ListCertificates',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryCertificatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/AddCertificate',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/DeleteCertificate',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPasswords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/ListPasswords',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryPasswordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/AddPassword',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddRegistryPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/DeletePassword',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteRegistryPasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDeviceTopicAliases(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/ListDeviceTopicAliases',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDeviceTopicAliasesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListDataStreamExports(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/ListDataStreamExports',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListDataStreamExportsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddDataStreamExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/AddDataStreamExport',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.AddDataStreamExportRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteDataStreamExport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/DeleteDataStreamExport',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.DeleteDataStreamExportRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.RegistryService/ListOperations',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_registry__service__pb2.ListRegistryOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/api_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1 import api_key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_api__key__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/iam/v1/api_key_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a!yandex/cloud/iam/v1/api_key.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"4\n\x10GetApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"y\n\x12ListApiKeysRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"]\n\x13ListApiKeysResponse\x12-\n\x08\x61pi_keys\x18\x01 \x03(\x0b\x32\x1b.yandex.cloud.iam.v1.ApiKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa5\x01\n\x13\x43reateApiKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x18\n\x05scope\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"T\n\x14\x43reateApiKeyResponse\x12,\n\x07\x61pi_key\x18\x01 \x01(\x0b\x32\x1b.yandex.cloud.iam.v1.ApiKey\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x88\x01\n\x13UpdateApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"*\n\x14UpdateApiKeyMetadata\x12\x12\n\napi_key_id\x18\x01 \x01(\t\"7\n\x13\x44\x65leteApiKeyRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"*\n\x14\x44\x65leteApiKeyMetadata\x12\x12\n\napi_key_id\x18\x01 \x01(\t\"~\n\x1bListApiKeyOperationsRequest\x12 \n\napi_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"n\n\x1cListApiKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xea\x06\n\rApiKeyService\x12r\n\x04List\x12\'.yandex.cloud.iam.v1.ListApiKeysRequest\x1a(.yandex.cloud.iam.v1.ListApiKeysResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/iam/v1/apiKeys\x12o\n\x03Get\x12%.yandex.cloud.iam.v1.GetApiKeyRequest\x1a\x1b.yandex.cloud.iam.v1.ApiKey\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/iam/v1/apiKeys/{api_key_id}\x12y\n\x06\x43reate\x12(.yandex.cloud.iam.v1.CreateApiKeyRequest\x1a).yandex.cloud.iam.v1.CreateApiKeyResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/iam/v1/apiKeys:\x01*\x12\xa0\x01\n\x06Update\x12(.yandex.cloud.iam.v1.UpdateApiKeyRequest\x1a!.yandex.cloud.operation.Operation\"I\xb2\xd2*\x1e\n\x14UpdateApiKeyMetadata\x12\x06\x41piKey\x82\xd3\xe4\x93\x02!2\x1c/iam/v1/apiKeys/{api_key_id}:\x01*\x12\xac\x01\n\x06\x44\x65lete\x12(.yandex.cloud.iam.v1.DeleteApiKeyRequest\x1a!.yandex.cloud.operation.Operation\"U\xb2\xd2*-\n\x14\x44\x65leteApiKeyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x1e*\x1c/iam/v1/apiKeys/{api_key_id}\x12\xa6\x01\n\x0eListOperations\x12\x30.yandex.cloud.iam.v1.ListApiKeyOperationsRequest\x1a\x31.yandex.cloud.iam.v1.ListApiKeyOperationsResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/iam/v1/apiKeys/{api_key_id}/operationsBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.api_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _GETAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
  _GETAPIKEYREQUEST.fields_by_name['api_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTAPIKEYSREQUEST.fields_by_name['service_account_id']._options = None
  _LISTAPIKEYSREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _LISTAPIKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTAPIKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTAPIKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTAPIKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEAPIKEYREQUEST.fields_by_name['service_account_id']._options = None
  _CREATEAPIKEYREQUEST.fields_by_name['service_account_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEAPIKEYREQUEST.fields_by_name['description']._options = None
  _CREATEAPIKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _CREATEAPIKEYREQUEST.fields_by_name['scope']._options = None
  _CREATEAPIKEYREQUEST.fields_by_name['scope']._serialized_options = b'\212\3101\005<=256'
  _UPDATEAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
  _UPDATEAPIKEYREQUEST.fields_by_name['api_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEAPIKEYREQUEST.fields_by_name['description']._options = None
  _UPDATEAPIKEYREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _DELETEAPIKEYREQUEST.fields_by_name['api_key_id']._options = None
  _DELETEAPIKEYREQUEST.fields_by_name['api_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['api_key_id']._options = None
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['api_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTAPIKEYOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _APIKEYSERVICE.methods_by_name['List']._options = None
  _APIKEYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\021\022\017/iam/v1/apiKeys'
  _APIKEYSERVICE.methods_by_name['Get']._options = None
  _APIKEYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\036\022\034/iam/v1/apiKeys/{api_key_id}'
  _APIKEYSERVICE.methods_by_name['Create']._options = None
  _APIKEYSERVICE.methods_by_name['Create']._serialized_options = b'\202\323\344\223\002\024\"\017/iam/v1/apiKeys:\001*'
  _APIKEYSERVICE.methods_by_name['Update']._options = None
  _APIKEYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdateApiKeyMetadata\022\006ApiKey\202\323\344\223\002!2\034/iam/v1/apiKeys/{api_key_id}:\001*'
  _APIKEYSERVICE.methods_by_name['Delete']._options = None
  _APIKEYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeleteApiKeyMetadata\022\025google.protobuf.Empty\202\323\344\223\002\036*\034/iam/v1/apiKeys/{api_key_id}'
  _APIKEYSERVICE.methods_by_name['ListOperations']._options = None
  _APIKEYSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002)\022\'/iam/v1/apiKeys/{api_key_id}/operations'
  _globals['_GETAPIKEYREQUEST']._serialized_start=303
  _globals['_GETAPIKEYREQUEST']._serialized_end=355
  _globals['_LISTAPIKEYSREQUEST']._serialized_start=357
  _globals['_LISTAPIKEYSREQUEST']._serialized_end=478
  _globals['_LISTAPIKEYSRESPONSE']._serialized_start=480
  _globals['_LISTAPIKEYSRESPONSE']._serialized_end=573
  _globals['_CREATEAPIKEYREQUEST']._serialized_start=576
  _globals['_CREATEAPIKEYREQUEST']._serialized_end=741
  _globals['_CREATEAPIKEYRESPONSE']._serialized_start=743
  _globals['_CREATEAPIKEYRESPONSE']._serialized_end=827
  _globals['_UPDATEAPIKEYREQUEST']._serialized_start=830
  _globals['_UPDATEAPIKEYREQUEST']._serialized_end=966
  _globals['_UPDATEAPIKEYMETADATA']._serialized_start=968
  _globals['_UPDATEAPIKEYMETADATA']._serialized_end=1010
  _globals['_DELETEAPIKEYREQUEST']._serialized_start=1012
  _globals['_DELETEAPIKEYREQUEST']._serialized_end=1067
  _globals['_DELETEAPIKEYMETADATA']._serialized_start=1069
  _globals['_DELETEAPIKEYMETADATA']._serialized_end=1111
  _globals['_LISTAPIKEYOPERATIONSREQUEST']._serialized_start=1113
  _globals['_LISTAPIKEYOPERATIONSREQUEST']._serialized_end=1239
  _globals['_LISTAPIKEYOPERATIONSRESPONSE']._serialized_start=1241
  _globals['_LISTAPIKEYOPERATIONSRESPONSE']._serialized_end=1351
  _globals['_APIKEYSERVICE']._serialized_start=1354
  _globals['_APIKEYSERVICE']._serialized_end=2228
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/agent/v1/job_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3yandex/cloud/loadtesting/agent/v1/job_service.proto\x12!yandex.cloud.loadtesting.agent.v1\x1a\x1cgoogle/api/annotations.proto\"\xe4\x02\n\x03Job\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x35\n\x04\x61mmo\x18\x03 \x01(\x0b\x32\'.yandex.cloud.loadtesting.agent.v1.File\x12\x1c\n\x14logging_log_group_id\x18\x04 \x01(\t\x12\x43\n\ttest_data\x18\x05 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\x12\x46\n\x0c\x64\x61ta_payload\x18\x06 \x03(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.TestDataEntry\x12_\n\x18\x61rtifact_upload_settings\x18\x07 \x01(\x0b\x32=.yandex.cloud.loadtesting.agent.v1.TestArtifactUploadSettings\"%\n\x04\x46ile\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"O\n\rStorageObject\x12\x1d\n\x15object_storage_bucket\x18\x01 \x01(\t\x12\x1f\n\x17object_storage_filename\x18\x02 \x01(\t\"}\n\rTestDataEntry\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cis_transient\x18\x02 \x01(\x08\x12H\n\x0estorage_object\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.loadtesting.agent.v1.StorageObject\"\x8c\x01\n\x1aTestArtifactUploadSettings\x12\x15\n\routput_bucket\x18\x01 \x01(\t\x12\x13\n\x0boutput_name\x18\x02 \x01(\t\x12\x12\n\nis_archive\x18\x03 \x01(\x08\x12\x16\n\x0e\x66ilter_include\x18\x04 \x03(\t\x12\x16\n\x0e\x66ilter_exclude\x18\x05 \x03(\t\"3\n\x13GetJobTransientFile\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"W\n\rGetJobRequest\x12\x1b\n\x13\x63ompute_instance_id\x18\x01 \x01(\t\x12\x19\n\x11\x61gent_instance_id\x18\x02 \x01(\t\x12\x0e\n\x06job_id\x18\x03 \x01(\t\"\xed\x02\n\x15\x43laimJobStatusRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12R\n\x06status\x18\x02 \x01(\x0e\x32\x42.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest.JobStatus\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"\xe0\x01\n\tJobStatus\x12\x1a\n\x16JOB_STATUS_UNSPECIFIED\x10\x00\x12\x10\n\x0cPOST_PROCESS\x10\x01\x12\r\n\tINITIATED\x10\x02\x12\r\n\tPREPARING\x10\x03\x12\x11\n\tNOT_FOUND\x10\x04\x1a\x02\x08\x01\x12\x0b\n\x07RUNNING\x10\x05\x12\r\n\tFINISHING\x10\x06\x12\x0c\n\x08\x46INISHED\x10\x07\x12\x0b\n\x07STOPPED\x10\x08\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0f\n\x0b\x41UTOSTOPPED\x10\n\x12 \n\x1cWAITING_FOR_A_COMMAND_TO_RUN\x10\x0b\"&\n\x16\x43laimJobStatusResponse\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x03\"\"\n\x10JobSignalRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"\xc9\x01\n\x11JobSignalResponse\x12K\n\x06signal\x18\x01 \x01(\x0e\x32;.yandex.cloud.loadtesting.agent.v1.JobSignalResponse.Signal\x12\x15\n\rwait_duration\x18\x02 \x01(\x01\x12\x0e\n\x06run_in\x18\x03 \x01(\x01\"@\n\x06Signal\x12\x16\n\x12SIGNAL_UNSPECIFIED\x10\x00\x12\x08\n\x04STOP\x10\x01\x12\x08\n\x04WAIT\x10\x02\x12\n\n\x06RUN_IN\x10\x03\x32\xfb\x05\n\nJobService\x12\xbe\x01\n\x0b\x43laimStatus\x12\x38.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusRequest\x1a\x39.yandex.cloud.loadtesting.agent.v1.ClaimJobStatusResponse\":\x82\xd3\xe4\x93\x02\x34\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\x01*\x12\xc7\x01\n\x03Get\x12\x30.yandex.cloud.loadtesting.agent.v1.GetJobRequest\x1a&.yandex.cloud.loadtesting.agent.v1.Job\"f\x82\xd3\xe4\x93\x02`\x12\x37/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\x12#/loadtesting/agent/v1/jobs/{job_id}\x12\xad\x01\n\tGetSignal\x12\x33.yandex.cloud.loadtesting.agent.v1.JobSignalRequest\x1a\x34.yandex.cloud.loadtesting.agent.v1.JobSignalResponse\"5\x82\xd3\xe4\x93\x02/\x12-/loadtesting/agent/v1/jobs/{job_id}/getSignal\x12\xb1\x01\n\x10GetTransientFile\x12\x36.yandex.cloud.loadtesting.agent.v1.GetJobTransientFile\x1a\'.yandex.cloud.loadtesting.agent.v1.File\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/loadtesting/agent/v1/jobs/{job_id}/getTransientFileBt\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agentb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.agent.v1.job_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.loadtesting.agent.v1ZKgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/agent/v1;agent'
  _CLAIMJOBSTATUSREQUEST_JOBSTATUS.values_by_name["NOT_FOUND"]._options = None
  _CLAIMJOBSTATUSREQUEST_JOBSTATUS.values_by_name["NOT_FOUND"]._serialized_options = b'\010\001'
  _JOBSERVICE.methods_by_name['ClaimStatus']._options = None
  _JOBSERVICE.methods_by_name['ClaimStatus']._serialized_options = b'\202\323\344\223\0024\"//loadtesting/agent/v1/jobs/{job_id}/claimStatus:\001*'
  _JOBSERVICE.methods_by_name['Get']._options = None
  _JOBSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002`\0227/loadtesting/agent/v1/agents/{agent_instance_id}/getJobZ%\022#/loadtesting/agent/v1/jobs/{job_id}'
  _JOBSERVICE.methods_by_name['GetSignal']._options = None
  _JOBSERVICE.methods_by_name['GetSignal']._serialized_options = b'\202\323\344\223\002/\022-/loadtesting/agent/v1/jobs/{job_id}/getSignal'
  _JOBSERVICE.methods_by_name['GetTransientFile']._options = None
  _JOBSERVICE.methods_by_name['GetTransientFile']._serialized_options = b'\202\323\344\223\0026\0224/loadtesting/agent/v1/jobs/{job_id}/getTransientFile'
  _globals['_JOB']._serialized_start=121
  _globals['_JOB']._serialized_end=477
  _globals['_FILE']._serialized_start=479
  _globals['_FILE']._serialized_end=516
  _globals['_STORAGEOBJECT']._serialized_start=518
  _globals['_STORAGEOBJECT']._serialized_end=597
  _globals['_TESTDATAENTRY']._serialized_start=599
  _globals['_TESTDATAENTRY']._serialized_end=724
  _globals['_TESTARTIFACTUPLOADSETTINGS']._serialized_start=727
  _globals['_TESTARTIFACTUPLOADSETTINGS']._serialized_end=867
  _globals['_GETJOBTRANSIENTFILE']._serialized_start=869
  _globals['_GETJOBTRANSIENTFILE']._serialized_end=920
  _globals['_GETJOBREQUEST']._serialized_start=922
  _globals['_GETJOBREQUEST']._serialized_end=1009
  _globals['_CLAIMJOBSTATUSREQUEST']._serialized_start=1012
  _globals['_CLAIMJOBSTATUSREQUEST']._serialized_end=1377
  _globals['_CLAIMJOBSTATUSREQUEST_JOBSTATUS']._serialized_start=1153
  _globals['_CLAIMJOBSTATUSREQUEST_JOBSTATUS']._serialized_end=1377
  _globals['_CLAIMJOBSTATUSRESPONSE']._serialized_start=1379
  _globals['_CLAIMJOBSTATUSRESPONSE']._serialized_end=1417
  _globals['_JOBSIGNALREQUEST']._serialized_start=1419
  _globals['_JOBSIGNALREQUEST']._serialized_end=1453
  _globals['_JOBSIGNALRESPONSE']._serialized_start=1456
  _globals['_JOBSIGNALRESPONSE']._serialized_end=1657
  _globals['_JOBSIGNALRESPONSE_SIGNAL']._serialized_start=1593
  _globals['_JOBSIGNALRESPONSE_SIGNAL']._serialized_end=1657
  _globals['_JOBSERVICE']._serialized_start=1660
  _globals['_JOBSERVICE']._serialized_end=2423
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/datatransfer/v1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.datatransfer.v1.endpoint import clickhouse_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_clickhouse__pb2
from yandex.cloud.datatransfer.v1.endpoint import common_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_common__pb2
from yandex.cloud.datatransfer.v1.endpoint import kafka_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_kafka__pb2
from yandex.cloud.datatransfer.v1.endpoint import metrika_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_metrika__pb2
from yandex.cloud.datatransfer.v1.endpoint import mongo_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_mongo__pb2
from yandex.cloud.datatransfer.v1.endpoint import mysql_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_mysql__pb2
from yandex.cloud.datatransfer.v1.endpoint import postgres_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_postgres__pb2
from yandex.cloud.datatransfer.v1.endpoint import ydb_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_ydb__pb2
from yandex.cloud.datatransfer.v1.endpoint import yds_pb2 as yandex_dot_cloud_dot_datatransfer_dot_v1_dot_endpoint_dot_yds__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/datatransfer/v1/endpoint.proto\x12\x1cyandex.cloud.datatransfer.v1\x1a\x36yandex/cloud/datatransfer/v1/endpoint/clickhouse.proto\x1a\x32yandex/cloud/datatransfer/v1/endpoint/common.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/kafka.proto\x1a\x33yandex/cloud/datatransfer/v1/endpoint/metrika.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/mongo.proto\x1a\x31yandex/cloud/datatransfer/v1/endpoint/mysql.proto\x1a\x34yandex/cloud/datatransfer/v1/endpoint/postgres.proto\x1a/yandex/cloud/datatransfer/v1/endpoint/ydb.proto\x1a/yandex/cloud/datatransfer/v1/endpoint/yds.proto\"\x8d\x02\n\x08\x45ndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x42\n\x06labels\x18\x06 \x03(\x0b\x32\x32.yandex.cloud.datatransfer.v1.Endpoint.LabelsEntry\x12@\n\x08settings\x18\x34 \x01(\x0b\x32..yandex.cloud.datatransfer.v1.EndpointSettings\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01J\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x34\"\xd5\t\n\x10\x45ndpointSettings\x12J\n\x0cmysql_source\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MysqlSourceH\x00\x12P\n\x0fpostgres_source\x18\x02 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.PostgresSourceH\x00\x12\x46\n\nydb_source\x18\x03 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YdbSourceH\x00\x12\x46\n\nyds_source\x18\x07 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YDSSourceH\x00\x12J\n\x0ckafka_source\x18\x08 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.KafkaSourceH\x00\x12J\n\x0cmongo_source\x18\t \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MongoSourceH\x00\x12T\n\x11\x63lickhouse_source\x18\x10 \x01(\x0b\x32\x37.yandex.cloud.datatransfer.v1.endpoint.ClickhouseSourceH\x00\x12J\n\x0cmysql_target\x18\x65 \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MysqlTargetH\x00\x12P\n\x0fpostgres_target\x18\x66 \x01(\x0b\x32\x35.yandex.cloud.datatransfer.v1.endpoint.PostgresTargetH\x00\x12T\n\x11\x63lickhouse_target\x18h \x01(\x0b\x32\x37.yandex.cloud.datatransfer.v1.endpoint.ClickhouseTargetH\x00\x12\x46\n\nydb_target\x18i \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YdbTargetH\x00\x12J\n\x0ckafka_target\x18n \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.KafkaTargetH\x00\x12J\n\x0cmongo_target\x18o \x01(\x0b\x32\x32.yandex.cloud.datatransfer.v1.endpoint.MongoTargetH\x00\x12O\n\x0emetrika_source\x18\x92\x01 \x01(\x0b\x32\x34.yandex.cloud.datatransfer.v1.endpoint.MetrikaSourceH\x00\x12G\n\nyds_target\x18\x96\x01 \x01(\x0b\x32\x30.yandex.cloud.datatransfer.v1.endpoint.YDSTargetH\x00\x42\n\n\x08settingsJ\x04\x08\x04\x10\x07J\x04\x08\n\x10\x10J\x04\x08\x11\x10\x65J\x04\x08g\x10hJ\x04\x08j\x10nJ\x05\x08p\x10\x92\x01J\x06\x08\x93\x01\x10\x96\x01\x42q\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransferb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.datatransfer.v1.endpoint_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.datatransfer.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/datatransfer/v1;datatransfer'
  _ENDPOINT_LABELSENTRY._options = None
  _ENDPOINT_LABELSENTRY._serialized_options = b'8\001'
  _globals['_ENDPOINT']._serialized_start=544
  _globals['_ENDPOINT']._serialized_end=813
  _globals['_ENDPOINT_LABELSENTRY']._serialized_start=756
  _globals['_ENDPOINT_LABELSENTRY']._serialized_end=801
  _globals['_ENDPOINTSETTINGS']._serialized_start=816
  _globals['_ENDPOINTSETTINGS']._serialized_end=2053
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/clickhouse/v1/format_schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2yandex/cloud/mdb/clickhouse/v1/format_schema.proto\x12\x1eyandex.cloud.mdb.clickhouse.v1\"}\n\x0c\x46ormatSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x12\n\ncluster_id\x18\x02 \x01(\t\x12>\n\x04type\x18\x03 \x01(\x0e\x32\x30.yandex.cloud.mdb.clickhouse.v1.FormatSchemaType\x12\x0b\n\x03uri\x18\x04 \x01(\t*y\n\x10\x46ormatSchemaType\x12\"\n\x1e\x46ORMAT_SCHEMA_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46ORMAT_SCHEMA_TYPE_PROTOBUF\x10\x01\x12 \n\x1c\x46ORMAT_SCHEMA_TYPE_CAPNPROTO\x10\x02\x42s\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.clickhouse.v1.format_schema_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"yandex.cloud.api.mdb.clickhouse.v1ZMgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/clickhouse/v1;clickhouse'
  _globals['_FORMATSCHEMATYPE']._serialized_start=213
  _globals['_FORMATSCHEMATYPE']._serialized_end=334
  _globals['_FORMATSCHEMA']._serialized_start=86
  _globals['_FORMATSCHEMA']._serialized_end=211
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.iot.devices.v1 import device_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2
from yandex.cloud.iot.devices.v1 import device_service_pb2 as yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class DeviceServiceStub(object):
    """A set of methods for managing devices.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/Get',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetDeviceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.FromString,
                )
        self.GetByName = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/GetByName',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetByNameDeviceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/List',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/Create',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.CreateDeviceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/Update',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.UpdateDeviceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/Delete',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListCertificates = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/ListCertificates',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesResponse.FromString,
                )
        self.AddCertificate = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/AddCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDeviceCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeleteCertificate = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/DeleteCertificate',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceCertificateRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListPasswords = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/ListPasswords',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsResponse.FromString,
                )
        self.AddPassword = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/AddPassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDevicePasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DeletePassword = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/DeletePassword',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDevicePasswordRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.iot.devices.v1.DeviceService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsResponse.FromString,
                )


class DeviceServiceServicer(object):
    """A set of methods for managing devices.
    """

    def Get(self, request, context):
        """Returns the specified device.

        To get the list of available devices, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetByName(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of devices in the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates a device in the specified registry.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListCertificates(self, request, context):
        """Retrieves the list of device certificates for the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCertificate(self, request, context):
        """Adds a certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteCertificate(self, request, context):
        """Deletes the specified device certificate.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPasswords(self, request, context):
        """Retrieves the list of passwords for the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddPassword(self, request, context):
        """Adds password for the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeletePassword(self, request, context):
        """Deletes the specified password.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified device.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DeviceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetDeviceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.SerializeToString,
            ),
            'GetByName': grpc.unary_unary_rpc_method_handler(
                    servicer.GetByName,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetByNameDeviceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.CreateDeviceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.UpdateDeviceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListCertificates': grpc.unary_unary_rpc_method_handler(
                    servicer.ListCertificates,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesResponse.SerializeToString,
            ),
            'AddCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.AddCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDeviceCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeleteCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteCertificate,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceCertificateRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListPasswords': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPasswords,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsResponse.SerializeToString,
            ),
            'AddPassword': grpc.unary_unary_rpc_method_handler(
                    servicer.AddPassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDevicePasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DeletePassword': grpc.unary_unary_rpc_method_handler(
                    servicer.DeletePassword,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDevicePasswordRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.iot.devices.v1.DeviceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class DeviceService(object):
    """A set of methods for managing devices.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/Get',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetDeviceRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetByName(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/GetByName',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.GetByNameDeviceRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__pb2.Device.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/List',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/Create',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.CreateDeviceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/Update',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.UpdateDeviceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/Delete',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListCertificates(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/ListCertificates',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceCertificatesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/AddCertificate',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDeviceCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/DeleteCertificate',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDeviceCertificateRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListPasswords(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/ListPasswords',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDevicePasswordsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddPassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/AddPassword',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.AddDevicePasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeletePassword(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/DeletePassword',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.DeleteDevicePasswordRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.iot.devices.v1.DeviceService/ListOperations',
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_iot_dot_devices_dot_v1_dot_device__service__pb2.ListDeviceOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/yandex_passport_user_account_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.iam.v1 import user_account_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_user__account__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/iam/v1/yandex_passport_user_account_service.proto\x12\x13yandex.cloud.iam.v1\x1a\x1cgoogle/api/annotations.proto\x1a&yandex/cloud/iam/v1/user_account.proto\x1a\x1dyandex/cloud/validation.proto\"3\n\x1cGetUserAccountByLoginRequest\x12\x13\n\x05login\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x32\xba\x01\n YandexPassportUserAccountService\x12\x95\x01\n\nGetByLogin\x12\x31.yandex.cloud.iam.v1.GetUserAccountByLoginRequest\x1a .yandex.cloud.iam.v1.UserAccount\"2\x82\xd3\xe4\x93\x02,\x12*/iam/v1/yandexPassportUserAccounts:byLoginBV\n\x17yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iamb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.yandex_passport_user_account_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.iam.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1;iam'
  _GETUSERACCOUNTBYLOGINREQUEST.fields_by_name['login']._options = None
  _GETUSERACCOUNTBYLOGINREQUEST.fields_by_name['login']._serialized_options = b'\350\3071\001'
  _YANDEXPASSPORTUSERACCOUNTSERVICE.methods_by_name['GetByLogin']._options = None
  _YANDEXPASSPORTUSERACCOUNTSERVICE.methods_by_name['GetByLogin']._serialized_options = b'\202\323\344\223\002,\022*/iam/v1/yandexPassportUserAccounts:byLogin'
  _globals['_GETUSERACCOUNTBYLOGINREQUEST']._serialized_start=188
  _globals['_GETUSERACCOUNTBYLOGINREQUEST']._serialized_end=239
  _globals['_YANDEXPASSPORTUSERACCOUNTSERVICE']._serialized_start=242
  _globals['_YANDEXPASSPORTUSERACCOUNTSERVICE']._serialized_end=428
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/backup/v1/policy_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.backup.v1 import policy_pb2 as yandex_dot_cloud_dot_backup_dot_v1_dot_policy__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+yandex/cloud/backup/v1/policy_service.proto\x12\x16yandex.cloud.backup.v1\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a#yandex/cloud/backup/v1/policy.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"O\n\x13ListPoliciesRequest\x12\x1b\n\tfolder_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\"H\n\x14ListPoliciesResponse\x12\x30\n\x08policies\x18\x01 \x03(\x0b\x32\x1e.yandex.cloud.backup.v1.Policy\"\x92\x01\n\x13\x43reatePolicyRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x03 \x01(\x0b\x32&.yandex.cloud.backup.v1.PolicySettingsB\x04\xe8\xc7\x31\x01\"7\n\x14\x43reatePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x10GetPolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"v\n\x13UpdatePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12>\n\x08settings\x18\x02 \x01(\x0b\x32&.yandex.cloud.backup.v1.PolicySettingsB\x04\xe8\xc7\x31\x01\"7\n\x14UpdatePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"6\n\x13\x44\x65letePolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"7\n\x14\x44\x65letePolicyMetadata\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"`\n\x12\x41pplyPolicyRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"E\n\x13\x41pplyPolicyMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\"n\n\x17ListApplicationsRequest\x12\x13\n\tfolder_id\x18\x01 \x01(\tH\x00\x12\x13\n\tpolicy_id\x18\x02 \x01(\tH\x00\x12\x1d\n\x13\x63ompute_instance_id\x18\x03 \x01(\tH\x00\x42\n\n\x02id\x12\x04\xc0\xc1\x31\x01\"[\n\x18ListApplicationsResponse\x12?\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32).yandex.cloud.backup.v1.PolicyApplication\"\\\n\x0e\x45xecuteRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"^\n\x0f\x45xecuteMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t\x12\x1b\n\x13progress_percentage\x18\x03 \x01(\x01\"[\n\rRevokeRequest\x12\x1f\n\tpolicy_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x63ompute_instance_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"@\n\x0eRevokeMetadata\x12\x11\n\tpolicy_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63ompute_instance_id\x18\x02 \x01(\t2\xd7\x0b\n\rPolicyService\x12~\n\x04List\x12+.yandex.cloud.backup.v1.ListPoliciesRequest\x1a,.yandex.cloud.backup.v1.ListPoliciesResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/backup/v1/policies\x12\x9a\x01\n\x06\x43reate\x12+.yandex.cloud.backup.v1.CreatePolicyRequest\x1a!.yandex.cloud.operation.Operation\"@\xb2\xd2*\x1e\n\x14\x43reatePolicyMetadata\x12\x06Policy\x82\xd3\xe4\x93\x02\x18\"\x13/backup/v1/policies:\x01*\x12x\n\x03Get\x12(.yandex.cloud.backup.v1.GetPolicyRequest\x1a\x1e.yandex.cloud.backup.v1.Policy\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/backup/v1/policies/{policy_id}\x12\xa6\x01\n\x06Update\x12+.yandex.cloud.backup.v1.UpdatePolicyRequest\x1a!.yandex.cloud.operation.Operation\"L\xb2\xd2*\x1e\n\x14UpdatePolicyMetadata\x12\x06Policy\x82\xd3\xe4\x93\x02$2\x1f/backup/v1/policies/{policy_id}:\x01*\x12\xb2\x01\n\x06\x44\x65lete\x12+.yandex.cloud.backup.v1.DeletePolicyRequest\x1a!.yandex.cloud.operation.Operation\"X\xb2\xd2*-\n\x14\x44\x65letePolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02!*\x1f/backup/v1/policies/{policy_id}\x12\xb8\x01\n\x05\x41pply\x12*.yandex.cloud.backup.v1.ApplyPolicyRequest\x1a!.yandex.cloud.operation.Operation\"`\xb2\xd2*,\n\x13\x41pplyPolicyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02*\"%/backup/v1/policies/{policy_id}:apply:\x01*\x12\xab\x01\n\x10ListApplications\x12/.yandex.cloud.backup.v1.ListApplicationsRequest\x1a\x30.yandex.cloud.backup.v1.ListApplicationsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/backup/v1/policies/{policy_id}/applications\x12\xb4\x01\n\x07\x45xecute\x12&.yandex.cloud.backup.v1.ExecuteRequest\x1a!.yandex.cloud.operation.Operation\"^\xb2\xd2*(\n\x0f\x45xecuteMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02,\"\'/backup/v1/policies/{policy_id}:execute:\x01*\x12\xb0\x01\n\x06Revoke\x12%.yandex.cloud.backup.v1.RevokeRequest\x1a!.yandex.cloud.operation.Operation\"\\\xb2\xd2*\'\n\x0eRevokeMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02+\"&/backup/v1/policies/{policy_id}:revoke:\x01*B_\n\x1ayandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backupb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.backup.v1.policy_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\032yandex.cloud.api.backup.v1ZAgithub.com/yandex-cloud/go-genproto/yandex/cloud/backup/v1;backup'
  _LISTPOLICIESREQUEST.fields_by_name['folder_id']._options = None
  _LISTPOLICIESREQUEST.fields_by_name['folder_id']._serialized_options = b'\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['folder_id']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['name']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEPOLICYREQUEST.fields_by_name['settings']._options = None
  _CREATEPOLICYREQUEST.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _CREATEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _CREATEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _GETPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _GETPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEPOLICYREQUEST.fields_by_name['settings']._options = None
  _UPDATEPOLICYREQUEST.fields_by_name['settings']._serialized_options = b'\350\3071\001'
  _UPDATEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _UPDATEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _DELETEPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEPOLICYMETADATA.fields_by_name['policy_id']._options = None
  _DELETEPOLICYMETADATA.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _APPLYPOLICYREQUEST.fields_by_name['policy_id']._options = None
  _APPLYPOLICYREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _APPLYPOLICYREQUEST.fields_by_name['compute_instance_id']._options = None
  _APPLYPOLICYREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTAPPLICATIONSREQUEST.oneofs_by_name['id']._options = None
  _LISTAPPLICATIONSREQUEST.oneofs_by_name['id']._serialized_options = b'\300\3011\001'
  _EXECUTEREQUEST.fields_by_name['policy_id']._options = None
  _EXECUTEREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _EXECUTEREQUEST.fields_by_name['compute_instance_id']._options = None
  _EXECUTEREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEREQUEST.fields_by_name['policy_id']._options = None
  _REVOKEREQUEST.fields_by_name['policy_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _REVOKEREQUEST.fields_by_name['compute_instance_id']._options = None
  _REVOKEREQUEST.fields_by_name['compute_instance_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _POLICYSERVICE.methods_by_name['List']._options = None
  _POLICYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\025\022\023/backup/v1/policies'
  _POLICYSERVICE.methods_by_name['Create']._options = None
  _POLICYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*\036\n\024CreatePolicyMetadata\022\006Policy\202\323\344\223\002\030\"\023/backup/v1/policies:\001*'
  _POLICYSERVICE.methods_by_name['Get']._options = None
  _POLICYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002!\022\037/backup/v1/policies/{policy_id}'
  _POLICYSERVICE.methods_by_name['Update']._options = None
  _POLICYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*\036\n\024UpdatePolicyMetadata\022\006Policy\202\323\344\223\002$2\037/backup/v1/policies/{policy_id}:\001*'
  _POLICYSERVICE.methods_by_name['Delete']._options = None
  _POLICYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*-\n\024DeletePolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002!*\037/backup/v1/policies/{policy_id}'
  _POLICYSERVICE.methods_by_name['Apply']._options = None
  _POLICYSERVICE.methods_by_name['Apply']._serialized_options = b'\262\322*,\n\023ApplyPolicyMetadata\022\025google.protobuf.Empty\202\323\344\223\002*\"%/backup/v1/policies/{policy_id}:apply:\001*'
  _POLICYSERVICE.methods_by_name['ListApplications']._options = None
  _POLICYSERVICE.methods_by_name['ListApplications']._serialized_options = b'\202\323\344\223\002.\022,/backup/v1/policies/{policy_id}/applications'
  _POLICYSERVICE.methods_by_name['Execute']._options = None
  _POLICYSERVICE.methods_by_name['Execute']._serialized_options = b'\262\322*(\n\017ExecuteMetadata\022\025google.protobuf.Empty\202\323\344\223\002,\"\'/backup/v1/policies/{policy_id}:execute:\001*'
  _POLICYSERVICE.methods_by_name['Revoke']._options = None
  _POLICYSERVICE.methods_by_name['Revoke']._serialized_options = b'\262\322*\'\n\016RevokeMetadata\022\025google.protobuf.Empty\202\323\344\223\002+\"&/backup/v1/policies/{policy_id}:revoke:\001*'
  _globals['_LISTPOLICIESREQUEST']._serialized_start=243
  _globals['_LISTPOLICIESREQUEST']._serialized_end=322
  _globals['_LISTPOLICIESRESPONSE']._serialized_start=324
  _globals['_LISTPOLICIESRESPONSE']._serialized_end=396
  _globals['_CREATEPOLICYREQUEST']._serialized_start=399
  _globals['_CREATEPOLICYREQUEST']._serialized_end=545
  _globals['_CREATEPOLICYMETADATA']._serialized_start=547
  _globals['_CREATEPOLICYMETADATA']._serialized_end=602
  _globals['_GETPOLICYREQUEST']._serialized_start=604
  _globals['_GETPOLICYREQUEST']._serialized_end=655
  _globals['_UPDATEPOLICYREQUEST']._serialized_start=657
  _globals['_UPDATEPOLICYREQUEST']._serialized_end=775
  _globals['_UPDATEPOLICYMETADATA']._serialized_start=777
  _globals['_UPDATEPOLICYMETADATA']._serialized_end=832
  _globals['_DELETEPOLICYREQUEST']._serialized_start=834
  _globals['_DELETEPOLICYREQUEST']._serialized_end=888
  _globals['_DELETEPOLICYMETADATA']._serialized_start=890
  _globals['_DELETEPOLICYMETADATA']._serialized_end=945
  _globals['_APPLYPOLICYREQUEST']._serialized_start=947
  _globals['_APPLYPOLICYREQUEST']._serialized_end=1043
  _globals['_APPLYPOLICYMETADATA']._serialized_start=1045
  _globals['_APPLYPOLICYMETADATA']._serialized_end=1114
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=1116
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=1226
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=1228
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=1319
  _globals['_EXECUTEREQUEST']._serialized_start=1321
  _globals['_EXECUTEREQUEST']._serialized_end=1413
  _globals['_EXECUTEMETADATA']._serialized_start=1415
  _globals['_EXECUTEMETADATA']._serialized_end=1509
  _globals['_REVOKEREQUEST']._serialized_start=1511
  _globals['_REVOKEREQUEST']._serialized_end=1602
  _globals['_REVOKEMETADATA']._serialized_start=1604
  _globals['_REVOKEMETADATA']._serialized_end=1668
  _globals['_POLICYSERVICE']._serialized_start=1671
  _globals['_POLICYSERVICE']._serialized_end=3166
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/user_ssh_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import user_ssh_key_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_user__ssh__key__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/organizationmanager/v1/user_ssh_key_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a yandex/cloud/api/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/user_ssh_key.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"=\n\x14GetUserSshKeyRequest\x12%\n\x0fuser_ssh_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x9c\x01\n\x16ListUserSshKeysRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1c\n\nsubject_id\x18\x02 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x03 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"u\n\x17ListUserSshKeysResponse\x12\x41\n\x08ssh_keys\x18\x01 \x03(\x0b\x32/.yandex.cloud.organizationmanager.v1.UserSshKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xca\x01\n\x17\x43reateUserSshKeyRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12 \n\nsubject_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=255\x12\x1d\n\x04\x64\x61ta\x18\x04 \x01(\tB\x0f\xe8\xc7\x31\x01\x8a\xc8\x31\x07<=20000\x12.\n\nexpires_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"L\n\x18\x43reateUserSshKeyMetadata\x12\x17\n\x0fuser_ssh_key_id\x18\x01 \x01(\t\x12\x17\n\x0forganization_id\x18\x02 \x01(\t\"\xba\x01\n\x17UpdateUserSshKeyRequest\x12%\n\x0fuser_ssh_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x17\n\x04name\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=255\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12.\n\nexpires_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"3\n\x18UpdateUserSshKeyMetadata\x12\x17\n\x0fuser_ssh_key_id\x18\x01 \x01(\t\"@\n\x17\x44\x65leteUserSshKeyRequest\x12%\n\x0fuser_ssh_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"3\n\x18\x44\x65leteUserSshKeyMetadata\x12\x17\n\x0fuser_ssh_key_id\x18\x01 \x01(\t2\xfa\x07\n\x11UserSshKeyService\x12\xb1\x01\n\x03Get\x12\x39.yandex.cloud.organizationmanager.v1.GetUserSshKeyRequest\x1a/.yandex.cloud.organizationmanager.v1.UserSshKey\">\x82\xd3\xe4\x93\x02\x38\x12\x36/organization-manager/v1/userSshKeys/{user_ssh_key_id}\x12\xaf\x01\n\x04List\x12;.yandex.cloud.organizationmanager.v1.ListUserSshKeysRequest\x1a<.yandex.cloud.organizationmanager.v1.ListUserSshKeysResponse\",\x82\xd3\xe4\x93\x02&\x12$/organization-manager/v1/userSshKeys\x12\xc4\x01\n\x06\x43reate\x12<.yandex.cloud.organizationmanager.v1.CreateUserSshKeyRequest\x1a!.yandex.cloud.operation.Operation\"Y\xb2\xd2*&\n\x18\x43reateUserSshKeyMetadata\x12\nUserSshKey\x82\xd3\xe4\x93\x02)\"$/organization-manager/v1/userSshKeys:\x01*\x12\xd6\x01\n\x06Update\x12<.yandex.cloud.organizationmanager.v1.UpdateUserSshKeyRequest\x1a!.yandex.cloud.operation.Operation\"k\xb2\xd2*&\n\x18UpdateUserSshKeyMetadata\x12\nUserSshKey\x82\xd3\xe4\x93\x02;26/organization-manager/v1/userSshKeys/{user_ssh_key_id}:\x01*\x12\xde\x01\n\x06\x44\x65lete\x12<.yandex.cloud.organizationmanager.v1.DeleteUserSshKeyRequest\x1a!.yandex.cloud.operation.Operation\"s\xb2\xd2*1\n\x18\x44\x65leteUserSshKeyMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x38*6/organization-manager/v1/userSshKeys/{user_ssh_key_id}B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.user_ssh_key_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _GETUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._options = None
  _GETUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSERSSHKEYSREQUEST.fields_by_name['organization_id']._options = None
  _LISTUSERSSHKEYSREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTUSERSSHKEYSREQUEST.fields_by_name['subject_id']._options = None
  _LISTUSERSSHKEYSREQUEST.fields_by_name['subject_id']._serialized_options = b'\212\3101\004<=50'
  _LISTUSERSSHKEYSREQUEST.fields_by_name['page_size']._options = None
  _LISTUSERSSHKEYSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTUSERSSHKEYSREQUEST.fields_by_name['page_token']._options = None
  _LISTUSERSSHKEYSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEUSERSSHKEYREQUEST.fields_by_name['organization_id']._options = None
  _CREATEUSERSSHKEYREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEUSERSSHKEYREQUEST.fields_by_name['subject_id']._options = None
  _CREATEUSERSSHKEYREQUEST.fields_by_name['subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEUSERSSHKEYREQUEST.fields_by_name['name']._options = None
  _CREATEUSERSSHKEYREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=255'
  _CREATEUSERSSHKEYREQUEST.fields_by_name['data']._options = None
  _CREATEUSERSSHKEYREQUEST.fields_by_name['data']._serialized_options = b'\350\3071\001\212\3101\007<=20000'
  _UPDATEUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._options = None
  _UPDATEUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEUSERSSHKEYREQUEST.fields_by_name['name']._options = None
  _UPDATEUSERSSHKEYREQUEST.fields_by_name['name']._serialized_options = b'\212\3101\005<=255'
  _DELETEUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._options = None
  _DELETEUSERSSHKEYREQUEST.fields_by_name['user_ssh_key_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _USERSSHKEYSERVICE.methods_by_name['Get']._options = None
  _USERSSHKEYSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\0028\0226/organization-manager/v1/userSshKeys/{user_ssh_key_id}'
  _USERSSHKEYSERVICE.methods_by_name['List']._options = None
  _USERSSHKEYSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002&\022$/organization-manager/v1/userSshKeys'
  _USERSSHKEYSERVICE.methods_by_name['Create']._options = None
  _USERSSHKEYSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*&\n\030CreateUserSshKeyMetadata\022\nUserSshKey\202\323\344\223\002)\"$/organization-manager/v1/userSshKeys:\001*'
  _USERSSHKEYSERVICE.methods_by_name['Update']._options = None
  _USERSSHKEYSERVICE.methods_by_name['Update']._serialized_options = b'\262\322*&\n\030UpdateUserSshKeyMetadata\022\nUserSshKey\202\323\344\223\002;26/organization-manager/v1/userSshKeys/{user_ssh_key_id}:\001*'
  _USERSSHKEYSERVICE.methods_by_name['Delete']._options = None
  _USERSSHKEYSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*1\n\030DeleteUserSshKeyMetadata\022\025google.protobuf.Empty\202\323\344\223\0028*6/organization-manager/v1/userSshKeys/{user_ssh_key_id}'
  _globals['_GETUSERSSHKEYREQUEST']._serialized_start=361
  _globals['_GETUSERSSHKEYREQUEST']._serialized_end=422
  _globals['_LISTUSERSSHKEYSREQUEST']._serialized_start=425
  _globals['_LISTUSERSSHKEYSREQUEST']._serialized_end=581
  _globals['_LISTUSERSSHKEYSRESPONSE']._serialized_start=583
  _globals['_LISTUSERSSHKEYSRESPONSE']._serialized_end=700
  _globals['_CREATEUSERSSHKEYREQUEST']._serialized_start=703
  _globals['_CREATEUSERSSHKEYREQUEST']._serialized_end=905
  _globals['_CREATEUSERSSHKEYMETADATA']._serialized_start=907
  _globals['_CREATEUSERSSHKEYMETADATA']._serialized_end=983
  _globals['_UPDATEUSERSSHKEYREQUEST']._serialized_start=986
  _globals['_UPDATEUSERSSHKEYREQUEST']._serialized_end=1172
  _globals['_UPDATEUSERSSHKEYMETADATA']._serialized_start=1174
  _globals['_UPDATEUSERSSHKEYMETADATA']._serialized_end=1225
  _globals['_DELETEUSERSSHKEYREQUEST']._serialized_start=1227
  _globals['_DELETEUSERSSHKEYREQUEST']._serialized_end=1291
  _globals['_DELETEUSERSSHKEYMETADATA']._serialized_start=1293
  _globals['_DELETEUSERSSHKEYMETADATA']._serialized_end=1344
  _globals['_USERSSHKEYSERVICE']._serialized_start=1347
  _globals['_USERSSHKEYSERVICE']._serialized_end=2365
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/mdb/redis/v1/backup_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2
from yandex.cloud.mdb.redis.v1 import backup_pb2 as yandex_dot_cloud_dot_mdb_dot_redis_dot_v1_dot_backup__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.yandex/cloud/mdb/redis/v1/backup_service.proto\x12\x19yandex.cloud.mdb.redis.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1dyandex/cloud/validation.proto\x1a&yandex/cloud/mdb/redis/v1/backup.proto\"+\n\x10GetBackupRequest\x12\x17\n\tbackup_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"s\n\x12ListBackupsRequest\x12\x1f\n\tfolder_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"b\n\x13ListBackupsResponse\x12\x32\n\x07\x62\x61\x63kups\x18\x01 \x03(\x0b\x32!.yandex.cloud.mdb.redis.v1.Backup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa1\x02\n\rBackupService\x12\x84\x01\n\x03Get\x12+.yandex.cloud.mdb.redis.v1.GetBackupRequest\x1a!.yandex.cloud.mdb.redis.v1.Backup\"-\x82\xd3\xe4\x93\x02\'\x12%/managed-redis/v1/backups/{backup_id}\x12\x88\x01\n\x04List\x12-.yandex.cloud.mdb.redis.v1.ListBackupsRequest\x1a..yandex.cloud.mdb.redis.v1.ListBackupsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/managed-redis/v1/backupsBd\n\x1dyandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redisb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.mdb.redis.v1.backup_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035yandex.cloud.api.mdb.redis.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/mdb/redis/v1;redis'
  _GETBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\350\3071\001'
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['folder_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._options = None
  _LISTBACKUPSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\005<=100'
  _BACKUPSERVICE.methods_by_name['Get']._options = None
  _BACKUPSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\'\022%/managed-redis/v1/backups/{backup_id}'
  _BACKUPSERVICE.methods_by_name['List']._options = None
  _BACKUPSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\033\022\031/managed-redis/v1/backups'
  _globals['_GETBACKUPREQUEST']._serialized_start=178
  _globals['_GETBACKUPREQUEST']._serialized_end=221
  _globals['_LISTBACKUPSREQUEST']._serialized_start=223
  _globals['_LISTBACKUPSREQUEST']._serialized_end=338
  _globals['_LISTBACKUPSRESPONSE']._serialized_start=340
  _globals['_LISTBACKUPSRESPONSE']._serialized_end=438
  _globals['_BACKUPSERVICE']._serialized_start=441
  _globals['_BACKUPSERVICE']._serialized_end=730
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/lockbox/v1/secret.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$yandex/cloud/lockbox/v1/secret.proto\x12\x17yandex.cloud.lockbox.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd4\x03\n\x06Secret\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12;\n\x06labels\x18\x06 \x03(\x0b\x32+.yandex.cloud.lockbox.v1.Secret.LabelsEntry\x12\x12\n\nkms_key_id\x18\x07 \x01(\t\x12\x36\n\x06status\x18\x08 \x01(\x0e\x32&.yandex.cloud.lockbox.v1.Secret.Status\x12\x39\n\x0f\x63urrent_version\x18\t \x01(\x0b\x32 .yandex.cloud.lockbox.v1.Version\x12\x1b\n\x13\x64\x65letion_protection\x18\n \x01(\x08\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08INACTIVE\x10\x03\"\xce\x02\n\x07Version\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tsecret_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndestroy_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x37\n\x06status\x18\x06 \x01(\x0e\x32\'.yandex.cloud.lockbox.v1.Version.Status\x12\x1a\n\x12payload_entry_keys\x18\x07 \x03(\t\"Z\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x1d\n\x19SCHEDULED_FOR_DESTRUCTION\x10\x02\x12\r\n\tDESTROYED\x10\x03\x42\x62\n\x1byandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockboxb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.lockbox.v1.secret_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033yandex.cloud.api.lockbox.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/lockbox/v1;lockbox'
  _SECRET_LABELSENTRY._options = None
  _SECRET_LABELSENTRY._serialized_options = b'8\001'
  _globals['_SECRET']._serialized_start=99
  _globals['_SECRET']._serialized_end=567
  _globals['_SECRET_LABELSENTRY']._serialized_start=448
  _globals['_SECRET_LABELSENTRY']._serialized_end=493
  _globals['_SECRET_STATUS']._serialized_start=495
  _globals['_SECRET_STATUS']._serialized_end=567
  _globals['_VERSION']._serialized_start=570
  _globals['_VERSION']._serialized_end=904
  _globals['_VERSION_STATUS']._serialized_start=814
  _globals['_VERSION_STATUS']._serialized_end=904
# @@protoc_insertion_point(module_scope)
